@@ -1,7 +1,10 @@
 from typing import Any, Optional
 import requests
 
+from coiote.v3.firmware_update import FirmwareUpdate
+
 from .auth import Authenticator
+from .v3.access import Access
 from .v3.assigned_device_properties import AssignedDeviceProperties
 from .v3.aws_integration import AwsIntegration
 from .v3.cert_auth import CertAuth
@@ -16,6 +19,7 @@ from .v3.device_monitoring import DeviceMonitoring
 from .v3.extensions import Extensions
 from .v3.groups import Groups
 from .v3.lifecycle_management import LifecycleManagement
+from .v3.model.access import AccessModel
 from .v3.observations import Observations
 from .v3.resources import Resources
 from .v3.sessions import Sessions
@@ -77,9 +81,11 @@ class Coiote:
         self.task_templates: TaskTemplates = self._make_module(TaskTemplates)
         self.tasks: Tasks = self._make_module(Tasks)
         self.users: Users = self._make_module(Users)
+        self.access: Access = self._make_module(Access)
+        self.firmware_update: FirmwareUpdate = self._make_module(FirmwareUpdate)
 
-    def _make_module(self, module_def):
-        return module_def(root_url=self.api_url, authenticator=self.authenticator, session=self.session)
+    def _make_module(self, module_class):
+        return module_class(root_url=self.api_url, authenticator=self.authenticator, session=self.session)
 
     def create_device_client(self, device_id: str) -> DeviceClient:
         return DeviceClient(device_id, self)
