@@ -16,18 +16,13 @@ class Resources(ApiEndpoint):
 
     @api_call(str)
     def create_resource(self, resource: Resource) -> Response:
-        print(asdict(resource))
         return self.session.post(self.get_url(), json=asdict(resource))
 
     @api_call_raw
     def upload_resource_data(self, resource_id: str, file: FileData):
         headers = {'Content-Type': 'application/octet-stream'}
         resource_id = sanitize_request_param(resource_id)
-        if isinstance(file, Base64FileData):
-            file_bytes = base64.b64decode(file.data)
-            return self.session.put(self.get_url(f"/{resource_id}/data"), data=file_bytes, headers=headers)
-        else:
-            raise ValueError("Invalid file type")
+        return self.session.put(self.get_url(f"/{resource_id}/data"), data=file.get_bytes(), headers=headers)
 
     @api_call(ResourceDownloadData)
     def get_resource_download_url(self, resource_id: str, options: DownloadOptions) -> Response:
